==> haskell-asn1-types-0.3.4-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 asn1-types
version:              0.3.4
visibility:           public
id:                   asn1-types-0.3.4-1fX7Cp5EHNDBwz7gqfkUvy
key:                  asn1-types-0.3.4-1fX7Cp5EHNDBwz7gqfkUvy
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-asn1
synopsis:             ASN.1 types
description:          ASN.1 standard types
category:             Data
abi:                  7bb0bd253982818de2e21399e5ed797c
exposed:              True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String

import-dirs:          /usr/lib/ghc-8.10.3/site-local/asn1-types-0.3.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/asn1-types-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/asn1-types-0.3.4
hs-libraries:         HSasn1-types-0.3.4-1fX7Cp5EHNDBwz7gqfkUvy
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    hourglass-0.2.12-6a091O0yhuJ6fpzz8qA716
    memory-0.15.0-E8yvrlcxsw5JtBytoHmuPe

haddock-interfaces:   /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html:         /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-types-0.3.4-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 asn1-types
version:              0.3.4
visibility:           public
id:                   asn1-types-0.3.4-C6qINnzV0M15PdEnoMULis
key:                  asn1-types-0.3.4-C6qINnzV0M15PdEnoMULis
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-asn1
synopsis:             ASN.1 types
description:          ASN.1 standard types
category:             Data
abi:                  530672f813e21b6a79067141d5a7bcd7
exposed:              True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String

import-dirs:          /usr/lib/ghc-8.10.3/site-local/asn1-types-0.3.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/asn1-types-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/asn1-types-0.3.4
hs-libraries:         HSasn1-types-0.3.4-C6qINnzV0M15PdEnoMULis
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    hourglass-0.2.12-HtpEyyTVTmGBao0oOfGIYZ
    memory-0.15.0-E8yvrlcxsw5JtBytoHmuPe

haddock-interfaces:   /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html:         /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
